@@ -8,10 +8,8 @@ use Carp;
 use DBI;
 use Getopt::Long qw(:config auto_help gnu_getopt);
 use Pod::Usage;
-use Try::Tiny;
 
 use App::WatchLater::YouTube;
-use App::WatchLater::Browser;
 
 =head1 NAME
 
@@ -19,11 +17,11 @@ App::WatchLater - Manage your YouTube Watch Later videos
 
 =head1 VERSION
 
-Version 0.03
+Version 0.01
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
@@ -58,25 +56,18 @@ SQL
 }
 
 sub _add {
-  my ($dbh, $api, $opts, @video_ids) = @_;
+  my ($dbh, $api, @video_ids) = @_;
 
-  my $on_conflict = $opts->{force} ? 'REPLACE' : 'IGNORE';
-
-  my $sth = $dbh->prepare_cached(<<SQL);
-INSERT OR $on_conflict INTO videos
+  my $sth = $dbh->prepare_cached(<<'SQL');
+INSERT OR REPLACE INTO videos
 (video_id, video_title, channel_id, channel_title, watched)
 VALUES (?, ?, ?, ?, 0);
 SQL
 
   for my $vid (@video_ids) {
-    try {
-      my $snippet = $api->get_video($vid);
-      $sth->execute($vid, $snippet->{title},
-                    $snippet->{channelId}, $snippet->{channelTitle});
-    } catch {
-      # warn the user and continue
-      print STDERR;
-    };
+    my $snippet = $api->get_video($vid);
+    $sth->execute($vid, $snippet->{title},
+                  $snippet->{channelId}, $snippet->{channelTitle});
   }
 }
 
@@ -93,6 +84,29 @@ SQL
   $row->{video_id};
 }
 
+sub _get_browser {
+  return $ENV{BROWSER} if exists $ENV{BROWSER};
+  for ($^O) {
+    if (/MSWin32/ || /cygwin/) {
+      return 'start';
+    }
+    if (/darwin/) {
+      return 'open';
+    }
+    if (/linux/) {
+      return 'xdg-open';
+    }
+    croak 'unsupported operating system';
+  }
+}
+
+sub _open_video {
+  my ($vid) = @_;
+  my $browser = _get_browser();
+  my $url = "https://youtu.be/$vid";
+  system { $browser } $browser, $url;
+}
+
 sub _mark_watched {
   my ($dbh, $vid) = @_;
   my $sth = $dbh->prepare(<<'SQL');
@@ -103,20 +117,15 @@ SQL
 }
 
 sub _watch {
-  my ($dbh, $api, $opts, @video_ids) = @_;
+  my ($dbh, $api, @video_ids) = @_;
 
   if (!@video_ids) {
     push @video_ids, _get_random_video($dbh);
   }
 
   for my $vid (@video_ids) {
-    try {
-      open_url("https://youtu.be/$vid") if $opts->{open};
-      _mark_watched($dbh, $vid);
-    } catch {
-      # warn the user and continue
-      print STDERR;
-    };
+    _open_video($vid);
+    _mark_watched($dbh, $vid);
   }
 }
 
@@ -131,26 +140,20 @@ directly from C<@ARGV> using L<Getopt::Long>.
 
 # TODO a better module interface to main()
 sub main {
-  my %opts = (
-    'db-path' => "$ENV{HOME}/.watch-later.db",
-    force     => 0,
-    open      => 1,
-  );
+  my $dbpath = "$ENV{HOME}/.watch-later.db";
+  my $add = 0;
+  my $watch = 0;
 
   GetOptions(
-    \%opts,
-    'db-path|d=s',
-    'add|a',
-    'watch|w',
-    'force|f!',
-    'open|o!',
+    'db-path|d=s' => \$dbpath,
+    'add|a'       => \$add,
+    'watch|w'     => \$watch,
   ) or pod2usage(2);
 
-  croak "Add and Watch modes both specified" if $opts{add} && $opts{watch};
+  croak "Add and Watch modes both specified" if $add && $watch;
 
-  my @video_ids = map { find_video_id($_) } @ARGV;
+  my $handler = $watch ? \&_watch : \&_add;
 
-  my $dbpath = $opts{'db-path'};
   my $dbh = DBI->connect("dbi:SQLite:dbname=$dbpath");
   _ensure_schema($dbh);
 
@@ -159,11 +162,7 @@ sub main {
     access_token => $ENV{YT_ACCESS_TOKEN},
   );
 
-  if ($opts{watch}) {
-    _watch($dbh, $api, \%opts, @video_ids);
-  } else {
-    _add($dbh, $api, \%opts, @video_ids);
-  }
+  $handler->($dbh, $api, map { find_video_id($_) } @ARGV);
 }
 
 =head1 AUTHOR
